#
# spec file for package ghc-vector
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name vector
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.12.0.1
Release:        lp150.1.8
Summary:        Efficient Arrays
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-rpm-macros
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-quickcheck2-devel
BuildRequires:  ghc-transformers-devel
%endif

%description
An efficient implementation of Int-indexed arrays (both mutable and immutable),
with a powerful loop optimisation framework .

It is structured as follows:

["Data.Vector"] Boxed vectors of arbitrary types.

["Data.Vector.Unboxed"] Unboxed vectors with an adaptive representation based
on data type families.

["Data.Vector.Storable"] Unboxed vectors of 'Storable' types.

["Data.Vector.Primitive"] Unboxed vectors of primitive types as defined by the
'primitive' package. "Data.Vector.Unboxed" is more flexible at no performance
cost.

["Data.Vector.Generic"] Generic interface to the vector types.

There is also a (draft) tutorial on common uses of vector.

* <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.12.0.1 revision 1.
* Mon Nov 21 2016 psimons@suse.com
- Update to version 0.11.0.0 revision 2 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.11.0.0 revision 1 with cabal2obs.
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 0.11.0.0
  * Define `Applicative` instances for `Data.Vector.Fusion.Util.{Box,Id}`
  * Define non-bottom `fail` for `instance Monad Vector`
  * New generalized stream fusion framework
  * Various safety fixes
  - Various overflows due to vector size have been eliminated
  - Memory is initialized on creation of unboxed vectors
  * Changes to SPEC usage to allow building under more conditions
* Tue Apr 14 2015 mimi.vx@gmail.com
- update to 0.10.12.3
  * Allow building with `primtive-0.6`
  * Add support for `deepseq-1.4.0.0`
  * Fixed compilation on non-head GHCs
  * Export MVector constructor from Data.Vector.Primitive to match Vector's
  (which was already exported).
  * Fix building on GHC 7.9 by adding Applicative instances for Id and Box
  * Support OverloadedLists for boxed Vector in GHC >= 7.8
  * Add support for OverloadedLists in GHC >= 7.8
  * Fix compilation with GHC 7.9
* Sat Oct 18 2014 peter.trommler@ohm-hochschule.de
- update to 0.10.9.1
  * no changelog
  * Haskell Platform 2014.2.0.0
- regenerate spec file
- drop vector-debian-no_ann_without_ghci.patch
  * we have ghci for all platforms now
* Sat Oct 18 2014 dvaleev@suse.com
- Fix PowerPC 64bit builds (vector-debian-no_ann_without_ghci.patch)
  https://ghc.haskell.org/trac/ghc/ticket/4268
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- BR ghc-deepseq-devel explicitly rather that relying on Cabal
  to pull it in
- more transparent packaging (fewer macros)
* Mon Jan  7 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service loaclonly for Factory submission
* Wed Oct 17 2012 peter.trommler@ohm-hochschule.de
- update to 0.10.0.1 from upstream (HP 2012.4.0.0 RC2)
* Tue Oct  2 2012 peter.trommler@ohm-hochschule.de
- update to 0.10 from upstream
- required by Haskell Platform 2012.4.0.0
* Thu May 17 2012 peter.trommler@ohm-hochschule.de
- spec file template generated by cabal2spec-0.25.5
* Wed Jan 18 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
